package com.fuint.common.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fuint.common.service.TableCategoryService;
import com.fuint.common.service.TableInfoService;
import com.fuint.repository.mapper.MtTableCategoryMapper;
import com.fuint.repository.mapper.MtTableInfoMapper;
import com.fuint.repository.model.MtTableCategory;
import com.fuint.repository.model.MtTableInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * 《餐桌》服务层
 */
@Service
public class TableInfoServiceImpl extends ServiceImpl<MtTableInfoMapper, MtTableInfo> implements TableInfoService {

	@Autowired
	private MtTableCategoryMapper tableCategoryMapper;

	/**
	 * 获取餐桌列表
	 *
	 * @param storeId 店铺id
	 * @return 结果
	 */
	@Override
	public List<MtTableInfo> selectTableListByStoreId(Long storeId, Long categoryId) {
		//通过店铺id获取店铺下的餐桌分类
		MtTableCategory mtTableCategory = tableCategoryMapper.selectOne(new LambdaQueryWrapper<MtTableCategory>()
				.select(MtTableCategory::getId,MtTableCategory::getStoreId)
				.eq(MtTableCategory::getId, categoryId));
		if (Objects.isNull(mtTableCategory) || !storeId.equals(mtTableCategory.getStoreId())) {
			return new ArrayList<>();
		}
		//返回结果
		return this.list(new LambdaQueryWrapper<MtTableInfo>()
				.select(MtTableInfo::getId, MtTableInfo::getTableNumber)
				.eq(MtTableInfo::getCategoryId, categoryId)
				.eq(MtTableInfo::getTableStatus, "A"));
	}
}
